Here go scripts that get automatically published in the system path.

Rather than linking internal projects directly to personal scripts rather compose the binaries here.
As it makes the rest of the code refactorable without breaking external dependencies that are not explicit.

For inspiration take a look at greimoire_test.
